@@ -34,12 +34,12 @@ class HRR_Chain : public ESS_Atom<HRR_Chain>
             std::shared_ptr<arma::uvec> outcomesIdx_, std::shared_ptr<arma::uvec> VSPredictorsIdx_,
             std::shared_ptr<arma::uvec> fixedPredictorIdx_, std::shared_ptr<arma::umat> missingDataArrayIdx_, std::shared_ptr<arma::uvec> completeCases_, 
             Gamma_Sampler_Type gamma_sampler_type_ , Gamma_Type gamma_type_ ,
-            Beta_Type beta_type_ , Covariance_Type covariance_type_ , bool output_CPO = false, int maxThreads = 1,
+            Beta_Type beta_type_ , Covariance_Type covariance_type_ , bool output_CPO = false, int maxThreads = 1, int tick = 1000, 
             double externalTemperature = 1. );
 
         HRR_Chain( Utils::SUR_Data& surData,
             Gamma_Sampler_Type gamma_sampler_type_ , Gamma_Type gamma_type_ ,
-            Beta_Type beta_type_ , Covariance_Type covariance_type_ , bool output_CPO = false, int maxThreads = 1,
+            Beta_Type beta_type_ , Covariance_Type covariance_type_ , bool output_CPO = false, int maxThreads = 1, int tick = 1000, 
             double externalTemperature = 1. );
 
         HRR_Chain( Utils::SUR_Data& surData, double externalTemperature = 1. );
@@ -431,6 +431,7 @@ class HRR_Chain : public ESS_Atom<HRR_Chain>
         unsigned int nFixedPredictors; // number of predictors to be kept no matter what
         bool output_CPO;
         int maxThreads;
+        int tick;
 
         // usefull quantities to keep track of
         arma::umat gammaMask;
